==> cutetube_1.7.0.tar.gz: cutetube-1.7.0/cutetubeapp/src/base/vimeouseralbumlistmodel.h <==
#ifndef VIMEOUSERALBUMLISTMODEL_H
#define VIMEOUSERALBUMLISTMODEL_H

#include "playlistitem.h"
#include <QAbstractListModel>
#include <QSharedPointer>

class Session;
class ThumbnailCache;

class VimeoUserAlbumListModel : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(Session* session
               READ session
               WRITE setSession)
    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)

public:
    enum Roles {
        IdRole = Qt::UserRole + 1,
        AlbumIdRole,
        TitleRole,
        ArtistRole,
        DateRole,
        VideoCountRole,
        ThumbnailRole,
        ThumbnailUrlRole,
        DescriptionRole
    };

public:
    explicit VimeoUserAlbumListModel(Session *session = 0, QObject *parent = 0);
    ~VimeoUserAlbumListModel() {}
    inline Session* session() const { return m_session; }
    void setSession(Session *session);
    inline ThumbnailCache* thumbnailCache() const { return m_cache; }
    void setThumbnailCache(ThumbnailCache *cache);
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    QSharedPointer<PlaylistItem> get(int row) const;
    Q_INVOKABLE PlaylistItem* getFromQML(int row) const;

private slots:
    void onAlbumAdded(int row);
    void onAlbumRemoved(int row);
    void onAlbumUpdated(int row);
    void onThumbnailReady();

signals:
    void countChanged(int count);

private:
    Session *m_session;
    ThumbnailCache *m_cache;
};

#endif // VIMEOUSERALBUMLISTMODEL_H

==> cutetube_1.10.9.tar.gz: cutetube-1.10.9/cutetubeapp/src/base/vimeouseralbumlistmodel.h <==
#ifndef VIMEOUSERALBUMLISTMODEL_H
#define VIMEOUSERALBUMLISTMODEL_H

#include "playlistitem.h"
#include <QAbstractListModel>
#include <QSharedPointer>

#ifndef QML_USER_INTERFACE
class ThumbnailCache;
#endif

class VimeoUserAlbumListModel : public QAbstractListModel
{
    Q_OBJECT

    Q_PROPERTY(int count
               READ rowCount
               NOTIFY countChanged)

public:
    enum Roles {
        IdRole = Qt::UserRole + 1,
        AlbumIdRole,
        TitleRole,
        ArtistRole,
        DateRole,
        VideoCountRole,
#ifndef QML_USER_INTERFACE
        ThumbnailRole,
#endif
        ThumbnailUrlRole,
        LargeThumbnailUrlRole,
        DescriptionRole
    };

public:
    explicit VimeoUserAlbumListModel(QObject *parent = 0);
    ~VimeoUserAlbumListModel();
#if QT_VERSION >= 0x050000
    QHash<int, QByteArray> roleNames() const;
#endif
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const;
    Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
    QSharedPointer<PlaylistItem> get(int row) const;
#ifdef QML_USER_INTERFACE
    Q_INVOKABLE PlaylistItem* getFromQML(int row) const;
#endif

private slots:
    void onAlbumAdded(int row);
    void onAlbumRemoved(int row);
    void onAlbumUpdated(int row);
#ifndef QML_USER_INTERFACE
    void onThumbnailReady();
#endif

signals:
    void countChanged(int count);

private:
#ifndef QML_USER_INTERFACE
    ThumbnailCache *m_cache;
#endif
    QHash<int, QByteArray> m_roleNames;
};

#endif // VIMEOUSERALBUMLISTMODEL_H
